Coverage for scipy\_lib\__init__.py: 0%

# Coverage for scipy\_lib\__init__.py : 0%

## 4 statements 0 run 4 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 | """ Module containing private utility functions =========================================== The ``scipy._lib`` namespace is empty (for now). Tests for all utilities in submodules of ``_lib`` can be run with:: from scipy import _lib _lib.test() """ from __future__ import division, print_function, absolute_import from scipy._lib._testutils import PytestTester test = PytestTester(__name__) del PytestTester